# UserSessionIdentifiers

parameters used to constrain which sessions will be acted on. (Revoked, deleted, etc)
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_id** | **str** | The unique id of the User associated with the session   | 
**org_id** | **str** | The unique id of the Organisation associated with the Issuer the user logged in to   | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


